/****************************************************************************
**
** Copyright (C) 2016 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 as published by the Free Software
** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
****************************************************************************/

#include "qmlprojectenvironmentaspect.h"

#include "qmlproject.h"

#include <projectexplorer/kit.h>
#include <projectexplorer/kitinformation.h>
#include <projectexplorer/target.h>

using namespace ProjectExplorer;
using namespace Utils;

namespace QmlProjectManager {

enum BaseEnvironmentBase {
    SystemEnvironmentBase = 0,
    CleanEnvironmentBase
};

Environment QmlProjectEnvironmentAspect::baseEnvironment() const
{
    Environment env = baseEnvironmentBase() == SystemEnvironmentBase
            ? Environment::systemEnvironment()
            : Environment();

    if (auto project = qobject_cast<const QmlProject *>(m_target->project()))
        env.modify(project->environment());

    return env;
}

QmlProjectEnvironmentAspect::QmlProjectEnvironmentAspect(Target *target)
    : m_target(target)
{
    if (DeviceTypeKitInformation::deviceTypeId(target->kit())
            == Constants::DESKTOP_DEVICE_TYPE)
        addPreferredBaseEnvironment(SystemEnvironmentBase, tr("System Environment"));

    addSupportedBaseEnvironment(CleanEnvironmentBase, tr("Clean Environment"));
}

} // namespace QmlProjectManager
